{ config, pkgs, lib, ... }:
let
  cfg = config.nix-config.style;
in
{
  services.swaync = {
    enable = true;

    settings = {
      control-center-margin-top = 13;
      control-center-margin-bottom = 0;
      control-center-margin-right = 14;
      control-center-margin-left = 0;
      notification-2fa-action = true;
      notification-inline-replies = true;
      notification-icon-size = 48;
      notification-body-image-height = 160;
      notification-body-image-width = 200;
      notification-window-width = 400;
      timeout = 6;
      timeout-low = 3;
      timeout-critical = 0;

      image-visibility = "when-available";
      transition-time = 200;
      hide-on-clear = false;
      hide-on-action = true;
      script-fail-notify = true;
      widgets = [
        "dnd"
        "buttons-grid"
        "mpris"
        "volume"
        "backlight"
        "title"
        "notifications"
      ];
      widget-config = {
        title = {
          text = "Notifications";
          clear-all-button = true;
          button-text = "";
        };
        dnd = {
          text = "Do Not Disturb";
        };
        label = {
          max-lines = 1;
          text = "Notification";
        };
        mpris = {
          image-size = 50;
          image-radius = 0;
        };
        volume = {
          label = "";
        };
        backlight = {
          label = "󰃠";
          device = "amdgpu_bl2";
        };
        buttons-grid = {
          actions = [
            {
              label = "";
              command = "wpctl set-mute @DEFAULT_AUDIO_SINK@ toggle";
              type = "toggle";
            }
            {
              label = "";
              command = "wpctl set-mute @DEFAULT_AUDIO_SOURCE@ toggle";
              type = "toggle";
            }
            {
              label = "󰤨";
              command = "nm-connection-editor";
            }
            {
              label = "󰂯";
              command = "blueman-manager";
            }
            {
              label = "󱡽";
              command = "bash -c $HOME/.config/hypr/scripts/airplaneMode.sh";
              type = "toggle";
            }
            {
              label = "";
              command = "shutdown now";
            }
            {
              label = "";
              command = "hyprlock";
            }
            {
              label = "";
              command = "~/.config/hypr/scripts/wlogout.sh";
            }
          ];
        };
      };
    };

    style = ''
      * {
        font-family: "monospace";
      }
    '';
  };
}
